@@ -366,19 +366,20 @@ function automation_snmp_item_remove_confirm() {
     ?>
     <script type='text/javascript'>
     $(function() {
-        $('#cdialog').dialog();
+		$('#cdialog').dialog();
+
+    	$('#continue').click(function(data) {
+			$.post('automation_snmp.php?action=item_remove', {
+				__csrf_magic: csrfMagicToken,
+				item_id: <?php print get_request_var('item_id');?>,
+				id: <?php print get_request_var('id');?>
+			}, function(data) {
+				$('#cdialog').dialog('close');
+				loadPageNoHeader('automation_snmp.php?action=edit&header=false&id=<?php print get_request_var('id');?>');
+			});
+		});
     });
 
-    $('#continue').click(function(data) {
-        $.post('automation_snmp.php?action=item_remove', {
-            __csrf_magic: csrfMagicToken,
-            item_id: <?php print get_request_var('item_id');?>,
-            id: <?php print get_request_var('id');?>
-        }, function(data) {
-            $('#cdialog').dialog('close');
-            loadPageNoHeader('automation_snmp.php?action=edit&header=false&id=<?php print get_request_var('id');?>');
-        });
-    });
     </script>
     <?php
 
@@ -886,7 +887,7 @@ function automation_snmp() {
 	form_end();
 
 	/* form the 'where' clause for our main sql query */
-	if (strlen(get_request_var('filter'))) {
+	if (get_request_var('filter') != '') {
 		$sql_where = "WHERE (automation_snmp.name LIKE '%" . get_request_var('filter') . "%')";
 	} else {
 		$sql_where = '';
