@@ -214,7 +214,7 @@ if ($config['poller_id'] > 1 || isset($rdatabase_hostname)) {
 	}
 } elseif (!db_connect_real($database_hostname, $database_username, $database_password, $database_default, $database_type, $database_port, $database_ssl)) {
 	print $config['is_web'] ? '<p>':'';
-	print 'FATAL: Connection to Cacti database failed. Please insure the database is running and your credentials in config.php are valid.';
+	print 'FATAL: Connection to Cacti database failed. Please ensure the database is running and your credentials in config.php are valid.';
 	print $config['is_web'] ? '</p>':'';
 	exit;
 } else {
@@ -235,8 +235,10 @@ if (isset($cacti_db_session) && $cacti_db_session && db_table_exists('sessions')
 	$cacti_db_session = false;
 }
 
-set_error_handler('CactiErrorHandler');
-register_shutdown_function('CactiShutdownHandler');
+if (!defined('IN_CACTI_INSTALL')) {
+	set_error_handler('CactiErrorHandler');
+	register_shutdown_function('CactiShutdownHandler');
+}
 
 /* verify the cacti database is initialized before moving past here */
 db_cacti_initialized($config['is_web']);
@@ -313,7 +315,6 @@ if ((bool)ini_get('register_globals')) {
 }
 
 include_once($config['include_path'] . '/global_languages.php');
-
 include_once($config['library_path'] . '/auth.php');
 include_once($config['library_path'] . '/plugins.php');
 include_once($config['include_path'] . '/plugins.php');
