@@ -225,7 +225,7 @@ function query_script_host($host_id, $snmp_query_id) {
 
 	if (!verify_index_order($script_queries)) {
 		query_debug_timer_offset('data_query', 'Invalid field &lt;index_order&gt;' . $script_queries['index_order'] . '&lt;/index_order&gt;');
-		query_debug_timer_offset('data_query', 'Must contain &lt;direction&gt;input&lt;/direction&gt; fields only');
+		query_debug_timer_offset('data_query', 'Must contain &lt;direction&gt;input&lt;/direction&gt; or &lt;direction&gt;input-output&lt;/direction&gt; fields only');
 		return false;
 	}
 
@@ -268,7 +268,7 @@ function query_script_host($host_id, $snmp_query_id) {
 	$output_array = array();
 
 	foreach ($script_queries['fields'] as $field_name => $field_array) {
-		if ($field_array['direction'] == 'input') {
+		if ($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output') {
 			$rewrite_value = isset($field_array['rewrite_value']) ? $field_array['rewrite_value'] : NULL;
 			$script_path = get_script_query_path((isset($script_queries['arg_prepend']) ? $script_queries['arg_prepend'] . ' ': '') . $script_queries['arg_query'] . ' ' . $field_array['query_name'], $script_queries['script_path'], $host_id);
 
@@ -292,6 +292,7 @@ function query_script_host($host_id, $snmp_query_id) {
 			debug_log_insert_section_end('data_query');
 		}
 	}
+
 	if (sizeof($output_array)) {
 		data_query_update_host_cache_from_buffer($host_id, $snmp_query_id, $output_array);
 	}
@@ -369,14 +370,15 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 	if (!verify_index_order($snmp_queries)) {
 		query_debug_timer_offset('data_query', 'Invalid field &lt;index_order&gt;' . $snmp_queries['index_order'] . '&lt;/index_order&gt;');
-		query_debug_timer_offset('data_query', 'Must contain &lt;direction&gt;input&lt;/direction&gt; fields only');
+		query_debug_timer_offset('data_query', 'Must contain &lt;direction&gt;input&lt;/direction&gt; or &lt;direction&gt;input-output&lt;/direction&gt; fields only');
 		return false;
 	}
 
 	$session = cacti_snmp_session($host['hostname'], $host['snmp_community'],
 		$host['snmp_version'], $host['snmp_username'], $host['snmp_password'],
 		$host['snmp_auth_protocol'], $host['snmp_priv_passphrase'], $host['snmp_priv_protocol'],
-		$host['snmp_context'], $host['snmp_engine_id'],  $host['snmp_port'], $host['snmp_timeout'], $host['ping_retries'], $host['max_oids']);
+		$host['snmp_context'], $host['snmp_engine_id'],  $host['snmp_port'], 
+		$host['snmp_timeout'], $host['ping_retries'], $host['max_oids']);
 
 	if ($session === FALSE) {
 		debug_log_insert('data_query', 'Failed to load SNMP session.');
@@ -433,7 +435,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 	rewrite_snmp_enum_value(NULL);
 
 	foreach ($snmp_queries['fields'] as $field_name => $field_array) {
-		if ($field_array['source'] != 'index' && $field_array['direction'] == 'input' && $field_array['method'] != 'get' &&
+		if ($field_array['source'] != 'index' && ($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output') && $field_array['method'] != 'get' &&
 			(isset($field_array['rewrite_index']) || isset($field_array['oid_suffix']))) {
 			$field_array['method'] = 'get';
 			debug_log_insert('data_query', "Fixing wrong 'method' field for '$field_name' since 'rewrite_index' or 'oid_suffix' is defined");
@@ -447,7 +449,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 				$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $rewrite_value, $value, $value, '');
 			}
-		} elseif (($field_array['method'] == 'get') && ($field_array['direction'] == 'input')) {
+		} elseif (($field_array['method'] == 'get') && ($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output')) {
 			query_debug_timer_offset('data_query', "Located input field '$field_name' [get]");
 
 			if ($field_array['source'] == 'value' && !isset($field_array['rewrite_index'])) {
@@ -471,7 +473,23 @@ function query_snmp_host($host_id, $snmp_query_id) {
 						query_debug_timer_offset('data_query', "oid_rewrite at OID: '" . $orig_oid . "' new OID: '" . $oid ."'");
 					}
 
-					$value = cacti_snmp_session_get($session, $oid);
+					if (isset($field_array['output_format'])) {
+						if ($field_array['output_format'] == 'hex') {
+							$value_output_format = SNMP_STRING_OUTPUT_HEX;
+						} elseif ($field_array['output_format'] == 'ascii') {
+							$value_output_format = SNMP_STRING_OUTPUT_ASCII;
+						} else {
+							$value_output_format = SNMP_STRING_OUTPUT_GUESS;
+						}
+
+						$value = cacti_snmp_get($host['hostname'], $host['snmp_community'], $oid, $host['snmp_version'],
+							$host['snmp_username'], $host['snmp_password'], $host['snmp_auth_protocol'], 
+							$host['snmp_priv_passphrase'], $host['snmp_priv_protocol'], $host['snmp_context'],
+							$host['snmp_port'], $host['snmp_timeout'], SNMP_POLLER, $host['snmp_engine_id'],
+							$value_output_format);
+					}else{
+						$value = cacti_snmp_session_get($session, $oid);
+					}
 
 					query_debug_timer_offset('data_query', "Executing SNMP get for data @ '$oid' [value='$value']");
 
@@ -481,7 +499,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 				$rewritten_indexes = array();
 				if (isset($field_array['rewrite_index'])){
 					$rewritten_indexes = data_query_rewrite_indexes($errmsg, $host_id, $snmp_query_id, $field_array['rewrite_index'], $snmp_indexes, $fields_processed);
-					if(sizeof($errmsg)){
+					if (sizeof($errmsg)){
 						foreach($errmsg as $message){
 							debug_log_insert('data_query', "Field '$field_name'" . $message);
 						}
@@ -491,8 +509,8 @@ function query_snmp_host($host_id, $snmp_query_id) {
 				$values = array();
 				foreach ($snmp_indexes as $index_oid => $index) {
 					$oid = $field_array['oid'];
-					if(isset($field_array['rewrite_index'])){
-						if(isset($rewritten_indexes[$index])){
+					if (isset($field_array['rewrite_index'])){
+						if (isset($rewritten_indexes[$index])){
 							$oid_suffix = $rewritten_indexes[$index];
 						} else {
 							// we failed to build rewritten index. warnings are sent already, just skip this index silently
@@ -505,7 +523,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 					$oid .= isset($field_array['oid_suffix']) ? ('.' . $field_array['oid_suffix']) : '';
 					$value = NULL;
-					if(substr($field_array['source'], 0, 11) == 'OID/REGEXP:'){
+					if (substr($field_array['source'], 0, 11) == 'OID/REGEXP:'){
 						$value = preg_replace('/' . str_replace('OID/REGEXP:', '', $field_array['source']) . '/', "\\1", $oid);
 					}
 
@@ -517,8 +535,28 @@ function query_snmp_host($host_id, $snmp_query_id) {
 					foreach ($values as $key => $value){
 						$oids[] = $value['oid'];
 					}
+
 					debug_log_insert('data_query', 'Executing SNMP get for ' . count($oids) . ' oids');
-					$results = cacti_snmp_session_get($session, $oids);
+
+					if (isset($field_array['output_format'])) {
+						if ($field_array['output_format'] == 'hex') {
+							$value_output_format = SNMP_STRING_OUTPUT_HEX;
+						} elseif ($field_array['output_format'] == 'ascii') {
+							$value_output_format = SNMP_STRING_OUTPUT_ASCII;
+						} else {
+							$value_output_format = SNMP_STRING_OUTPUT_GUESS;
+						}
+
+						foreach($oids as $oid) {
+							$results[$oid] = cacti_snmp_get($host['hostname'], $host['snmp_community'], $oid, $host['snmp_version'],
+								$host['snmp_username'], $host['snmp_password'], $host['snmp_auth_protocol'], 
+								$host['snmp_priv_passphrase'], $host['snmp_priv_protocol'], $host['snmp_context'],
+								$host['snmp_port'], $host['snmp_timeout'], SNMP_POLLER, $host['snmp_engine_id'],
+								$value_output_format);
+						}
+					}else{
+						$results = cacti_snmp_session_walk($session, $oids);
+					}
 
 					foreach (array_keys($values) as $key){
 						if (isset($results[$values[$key]['oid']])) {
@@ -527,7 +565,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 					}
 
 					foreach ($values as $key => $value) {
-						if(substr($field_array['source'], 0, 13) == 'VALUE/REGEXP:') {
+						if (substr($field_array['source'], 0, 13) == 'VALUE/REGEXP:') {
 							$values[$key]['value'] = preg_replace('/' . str_replace('VALUE/REGEXP:', '', $field_array['source']) . '/', "\\1", $values[$key]['value']);
 						}
 					}
@@ -543,7 +581,23 @@ function query_snmp_host($host_id, $snmp_query_id) {
 					$oid = $field_array['oid'] .  '.' . $index;
 					$oid .= isset($field_array['oid_suffix']) ? ('.' . $field_array['oid_suffix']) : '';
 
-					$value = cacti_snmp_session_get($session, $oid);
+					if (isset($field_array['output_format'])) {
+						if ($field_array['output_format'] == 'hex') {
+							$value_output_format = SNMP_STRING_OUTPUT_HEX;
+						} elseif ($field_array['output_format'] == 'ascii') {
+							$value_output_format = SNMP_STRING_OUTPUT_ASCII;
+						} else {
+							$value_output_format = SNMP_STRING_OUTPUT_GUESS;
+						}
+
+						$value = cacti_snmp_get($host['hostname'], $host['snmp_community'], $oid, $host['snmp_version'],
+							$host['snmp_username'], $host['snmp_password'], $host['snmp_auth_protocol'], 
+							$host['snmp_priv_passphrase'], $host['snmp_priv_protocol'], $host['snmp_context'],
+							$host['snmp_port'], $host['snmp_timeout'], SNMP_POLLER, $host['snmp_engine_id'],
+							$value_output_format);
+					}else{
+						$value = cacti_snmp_session_get($session, $oid);
+					}
 
 					$value = preg_replace('/' . str_replace('VALUE/REGEXP:', '', $field_array['source']) . '/', "\\1", $value);
 
@@ -552,16 +606,32 @@ function query_snmp_host($host_id, $snmp_query_id) {
 					$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $rewrite_value, $value, $index, $oid);
 				}
 			} 
-		} elseif (($field_array['method'] == 'walk') && ($field_array['direction'] == 'input')) {
+		} elseif ($field_array['method'] == 'walk' && ($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output')) {
 			debug_log_insert_section_start('data_query', "Click to show data query output for field '$field_name'");
 
 			query_debug_timer_offset('data_query', "Located input field '$field_name' [walk]");
 
-			$snmp_data = cacti_snmp_session_walk($session, $field_array['oid']);
+			if (isset($field_array['output_format'])) {
+				if ($field_array['output_format'] == 'hex') {
+					$value_output_format = SNMP_STRING_OUTPUT_HEX;
+				} elseif ($field_array['output_format'] == 'ascii') {
+					$value_output_format = SNMP_STRING_OUTPUT_ASCII;
+				} else {
+					$value_output_format = SNMP_STRING_OUTPUT_GUESS;
+				}
+
+				$snmp_data = cacti_snmp_walk($host['hostname'], $host['snmp_community'], $field_array['oid'], $host['snmp_version'],
+					$host['snmp_username'], $host['snmp_password'], $host['snmp_auth_protocol'], 
+					$host['snmp_priv_passphrase'], $host['snmp_priv_protocol'], $host['snmp_context'],
+					$host['snmp_port'], $host['snmp_timeout'], $host['ping_retries'], $host['max_oids'], SNMP_POLLER, 
+					$host['snmp_engine_id'], $value_output_format);
+			}else{
+				$snmp_data = cacti_snmp_session_walk($session, $field_array['oid']);
+			}
 
 			query_debug_timer_offset('data_query', "Executing SNMP walk for data @ '" . $field_array['oid'] . "'");
 
-			if (preg_match('/^VALUE\/TABLE:(.*)/',$field_array["source"],$matches)) {
+			if (preg_match('/^VALUE\/TABLE:(.*)/',$field_array['source'],$matches)) {
 				preg_match_all('/([^:]+):([^:]+)/',$matches[1],$match_temp);
 				$const_table = array_combine($match_temp[1],$match_temp[2]);
 			}
@@ -660,6 +730,8 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 			debug_log_insert_section_end('data_query');
 		}
+
+		$fields_processed[] = $field_name;
 	}
 
 	$session->close();
@@ -755,22 +827,24 @@ function data_query_rewrite_indexes(&$errmsg, $host_id, $snmp_query_id, $rewrite
 	$oid_items = explode('.', $rewrite_index);
 	$chain_indexes = array();
 	
-	if(!is_array($data_query_rewrite_indexes_cache))
+	if (!is_array($data_query_rewrite_indexes_cache))
 		$data_query_rewrite_indexes_cache = array();
 	
-	if(sizeof($oid_items)){
+	if (sizeof($oid_items)){
 	foreach($oid_items as $item){
 		$matches = array();
-		if(preg_match('/^\|query_([^|]+)\|$/', $item, $matches)){
-			$iv = mysql_real_escape_string($matches[1]);
-			if(is_array($fields_processed) && !in_array($iv, $fields_processed)){
+		if (preg_match('/^\|query_([^|]+)\|$/', $item, $matches)){
+			$iv = $matches[1];
+			if (is_array($fields_processed) && !in_array($iv, $fields_processed)){
 				$errmsg[] = "rewrite_index='$rewrite_index': '$iv' is not processed yet, could not use it as index source";
 					continue;
 			}
+
 			if (!isset($chain_indexes[$iv])) {
 				$hash =  "$host_id@$snmp_query_id@$iv";
 				if (!isset($data_query_rewrite_indexes_cache[$hash])) {
 					$data_query_rewrite_indexes_cache[$hash] = array();
+					$iv = db_qstr($iv);
 
 					$field_values = db_fetch_assoc_prepared("SELECT snmp_index, field_value
 						FROM host_snmp_cache
@@ -779,7 +853,7 @@ function data_query_rewrite_indexes(&$errmsg, $host_id, $snmp_query_id, $rewrite
 						AND field_name = ?", 
 						array($host_id, $snmp_query_id, $iv));
 
-					if(sizeof($field_values)){
+					if (sizeof($field_values)){
 						foreach($field_values as $item){
 							$data_query_rewrite_indexes_cache[$hash][$item['snmp_index']] = $item['field_value'];
 						}
@@ -795,14 +869,14 @@ function data_query_rewrite_indexes(&$errmsg, $host_id, $snmp_query_id, $rewrite
 	
 	$out = array();
 	$numeric_output = FALSE;
-	if(!is_array($snmp_indexes)){
+	if (!is_array($snmp_indexes)){
 		$snmp_indexes = array($snmp_indexes);
 		$numeric_output = TRUE;
 	}
 	foreach ($snmp_indexes as $oid => $num_index) {
 		$index = $rewrite_index;
 		foreach($chain_indexes as $key => $values){
-			if(isset($values[$num_index]) && preg_match('/^[0-9.]+$/', $values[$num_index])){
+			if (isset($values[$num_index]) && preg_match('/^[0-9.]+$/', $values[$num_index])){
 				$index = str_replace("|query_$key|", trim($values[$num_index]), $index);
 			} else {
 				$errmsg[] = "@'" . $num_index . "': could not load value of '$key'";
@@ -810,16 +884,16 @@ function data_query_rewrite_indexes(&$errmsg, $host_id, $snmp_query_id, $rewrite
 		}
 		
 		$index = str_replace('|index|', trim($num_index), $index);
-		if(!preg_match('/^[0-9.]*$/', $index)){
+		if (!preg_match('/^[0-9.]*$/', $index)){
 			$errmsg[] = "@'" . $num_index ."': some portions of rewrite_index field were not parsed: '$index'";
 			continue;
 		}
-		if($numeric_output){
+		if ($numeric_output){
 			return $index;
 		}
 		$out[$num_index] = $index;
 	}
-	if($numeric_output){
+	if ($numeric_output){
 		return NULL;
 	}
 	return $out;
@@ -833,51 +907,62 @@ function data_query_rewrite_indexes(&$errmsg, $host_id, $snmp_query_id, $rewrite
 function rewrite_snmp_enum_value($field_name, $value=NULL, $map=NULL){
 	static $mapcache = array();
 
-	if($field_name === NULL){
+	if ($field_name === NULL){
 		$mapcache = array();
+
 		return NULL;
 	}
-	if(is_array($map)){ # produced from XML, needs to be reformatted
+
+	if (is_array($map)){ # produced from XML, needs to be reformatted
 		$newmap = array();
 		foreach($map as $index => $item){
-			if(!isset($item['match']) || !isset($item['replace'])){
+			if (!isset($item['match']) || !isset($item['replace'])){
 				debug_log_insert('data_query', "Bogus rewrite_value item found, index='$index'");
 				continue;
 			}
+
 			$newmap[$item['match']] = $item['replace'];
 		}
+
 		$map = $newmap;
 	} else {
 		$map = unserialize($map);
 	}
-	if($map === FALSE || !is_array($map)){
+
+	if ($map === FALSE || !is_array($map)){
 		debug_log_insert('data_query', 'Could not parse translation map (rewrite_value)');
 		return $value;
 	}
-	if(!isset($mapcache[$field_name])){
+
+	if (!isset($mapcache[$field_name])){
 		$mapcache[$field_name] = array();
 		foreach($map as $src => $dst){
-			if(preg_match('/^REGEXP(NC)?:(.*)$/', $src, $matches)){
-				if($matches[1] == 'NC')
+			if (preg_match('/^REGEXP(NC)?:(.*)$/', $src, $matches)){
+				if ($matches[1] == 'NC') {
 					$src = '/' . str_replace('/', '\/', $matches[2]) . '/i';
-				else
+				} else {
 					$src = '/' . str_replace('/', '\/', $matches[1]) . '/';
+				}
 			} else {
 				$src = '/^' . str_replace('/^', '\/', $src) . '$/';
 			}
+
 			$mapcache[$field_name][$src] = $dst;
 		}
 	}
+
 	foreach($mapcache[$field_name] as $src => $dst){
-		if(preg_match($src, $value)){
+		if (preg_match($src, $value)){
 			$nvalue = preg_replace($src, $dst, $value);
 			debug_log_insert('data_query', "rewrite_value: '$value' => '$nvalue'");
 			$value = $nvalue;
 			break;
 		}
 	}
+
 	return $value;
 }
+
 /* data_query_index - returns an array containing the data query ID and index value given
 	a data query index type/value combination and a host ID
    @arg $index_type - the name of the index to match
@@ -949,13 +1034,13 @@ function decode_data_query_index($encoded_index, $data_query_id, $host_id) {
 		AND snmp_query_id = ?
 		GROUP BY snmp_index', array($host_id, $data_query_id));
 
-	if (sizeof($indexes) > 0) {
-	foreach ($indexes as $index) {
-		if (encode_data_query_index($index['snmp_index']) == $encoded_index) {
-			return $index['snmp_index'];
+	if (sizeof($indexes)) {
+		foreach ($indexes as $index) {
+			if (encode_data_query_index($index['snmp_index']) == $encoded_index) {
+				return $index['snmp_index'];
+			}
 		}
 	}
-	}
 }
 
 /* update_data_query_cache - updates the local data query cache for each graph AND data
@@ -969,11 +1054,12 @@ function update_data_query_cache($host_id, $data_query_id) {
 		AND snmp_query_id = ?',
 		array($host_id, $data_query_id));
 
-	if (sizeof($graphs) > 0) {
+	if (sizeof($graphs)) {
 		foreach ($graphs as $graph) {
 			update_graph_data_query_cache($graph['id'], $host_id, $data_query_id, $graph['snmp_index']);
 		}
 	}
+
 	query_debug_timer_offset('data_query', 'Update graph data query cache complete');
 
 	$data_sources = db_fetch_assoc_prepared('SELECT * 
@@ -990,6 +1076,7 @@ function update_data_query_cache($host_id, $data_query_id) {
 			}
 		}
 	}
+
 	query_debug_timer_offset('data_query', 'Update data source data query cache complete');
 }
 
@@ -1016,12 +1103,16 @@ function update_graph_data_query_cache($local_graph_id, $host_id = '', $data_que
 		WHERE graph_templates_item.task_item_id=data_template_rrd.id
 		AND data_template_rrd.local_data_id=data_template_data.local_data_id
 		AND graph_templates_item.local_graph_id = ?
-		LIMIT 1', array($local_graph_id)));
+		LIMIT 1', 
+		array($local_graph_id)));
 
 	if (empty($field)) { return; }
 
 	if (empty($data_query_id)) {
-		$data_query_id = db_fetch_cell_prepared('SELECT snmp_query_id FROM snmp_query_graph WHERE id = ?', array($field['output_type']));
+		$data_query_id = db_fetch_cell_prepared('SELECT snmp_query_id 
+			FROM snmp_query_graph 
+			WHERE id = ?', 
+			array($field['output_type']));
 	}
 
 	$index = data_query_index($field['index_type'], $field['index_value'], $host_id, $data_query_id);
@@ -1062,7 +1153,10 @@ function update_data_source_data_query_cache($local_data_id, $host_id = '', $dat
 	}
 
 	if (empty($data_query_id)) {
-		$data_query_id = db_fetch_cell_prepared('SELECT snmp_query_id FROM snmp_query_graph WHERE id = ?', array($field['output_type']));
+		$data_query_id = db_fetch_cell_prepared('SELECT snmp_query_id 
+			FROM snmp_query_graph 
+			WHERE id = ?', 
+			array($field['output_type']));
 	}
 
 	$index = data_query_index($field['index_type'], $field['index_value'], $host_id, $data_query_id);
@@ -1107,7 +1201,7 @@ function get_formatted_data_query_indexes($host_id, $data_query_id) {
 		array($host_id, $data_query_id));
 
 	/* in case no unique index is available, fallback to first field in XML */
-	if (strlen($sort_cache['sort_field']) == 0){
+	if ($sort_cache['sort_field'] == ''){
 		$snmp_queries = get_data_query_array($data_query_id);
 		if (isset($snmp_queries['index_order'])){
 			$i = explode(':', $snmp_queries['index_order']);
@@ -1196,7 +1290,7 @@ function get_ordered_index_type_list($host_id, $data_query_id, $data_query_index
 
 	/* list each of the input fields for this snmp query */
 	foreach ($raw_xml['fields'] as $field_name => $field_array) {
-		if ($field_array['direction'] == 'input') {
+		if ($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output') {
 			/* create a list of all values for this index */
 			if (sizeof($data_query_index_array) == 0) {
 				$field_values = db_fetch_assoc_prepared('SELECT field_value 
@@ -1353,7 +1447,7 @@ function verify_index_order($raw_xml) {
 
 	/* list each of the input fields for this snmp query */
 	foreach ($raw_xml['fields'] as $field_name => $field_array) {
-		if ($field_array['direction'] == 'input') {
+		if ($field_array['direction'] == 'input' || $field_array['direction'] == 'input-output') {
 			/* create a list of all values for this index */
 			array_push($xml_inputs, $field_name);
 		}
