@@ -197,7 +197,7 @@ function form_save() {
 
 			if ($poller_id) {
 				raise_message(1);
-			}else{
+			} else {
 				raise_message(2);
 			}
 		}
@@ -216,13 +216,13 @@ function form_actions() {
 	/* ================= input validation ================= */
 	get_filter_request_var('drp_action', FILTER_VALIDATE_REGEXP, array('options' => array('regexp' => '/^([a-zA-Z0-9_]+)$/')));
 	/* ==================================================== */
-	
+
 	/* if we are to save this form, instead of display it */
 	if (isset_request_var('selected_items')) {
 		$selected_items = sanitize_unserialize_selected_items(get_nfilter_request_var('selected_items'));
 
 		if ($selected_items != false) {
-			if (get_nfilter_request_var('drp_action') == '1') { /* delete */
+			if (get_nfilter_request_var('drp_action') == '1') { // delete
 				db_execute('DELETE FROM poller WHERE ' . array_to_sql_or($selected_items, 'id'));
 				db_execute('UPDATE host SET poller_id=1 WHERE ' . array_to_sql_or($selected_items, 'poller_id'));
 				db_execute('UPDATE automation_networks SET poller_id=1 WHERE ' . array_to_sql_or($selected_items, 'poller_id'));
@@ -233,15 +233,15 @@ function form_actions() {
 				db_execute('UPDATE poller_time SET poller_id=1 WHERE ' . array_to_sql_or($selected_items, 'poller_id'));
 
 				cacti_log('NOTE: The poller(s) with the id(s): ' . implode(',', $selected_items) . ' deleted by user ' . $_SESSION['sess_user_id'], false, 'WEBUI');
-			}elseif (get_request_var('drp_action') == '2') { /* disable */
+			} elseif (get_request_var('drp_action') == '2') { // disable
 				db_execute('UPDATE poller SET disabled="on" WHERE ' . array_to_sql_or($selected_items, 'id'));
 
 				cacti_log('NOTE: The poller(s) with the id(s): ' . implode(',', $selected_items) . ' disabled by user ' . $_SESSION['sess_user_id'], false, 'WEBUI');
-			}elseif (get_request_var('drp_action') == '3') { /* enable */
+			} elseif (get_request_var('drp_action') == '3') { // enable
 				db_execute('UPDATE poller SET disabled="" WHERE ' . array_to_sql_or($selected_items, 'id'));
 
 				cacti_log('NOTE: The poller(s) with the id(s): ' . implode(',', $selected_items) . ' enabled by user ' . $_SESSION['sess_user_id'], false, 'WEBUI');
-			}elseif (get_request_var('drp_action') == '4') { /* full sync */
+			} elseif (get_request_var('drp_action') == '4') { // full sync
 				foreach($selected_items as $item) {
 					replicate_out($item);
 				}
@@ -277,7 +277,7 @@ function form_actions() {
 	html_start_box($poller_actions{get_nfilter_request_var('drp_action')}, '60%', '', '3', 'center', '');
 
 	if (isset($poller_array) && sizeof($poller_array)) {
-		if (get_nfilter_request_var('drp_action') == '1') { /* delete */
+		if (get_nfilter_request_var('drp_action') == '1') { // delete
 			print "<tr>
 				<td class='textArea' class='odd'>
 					<p>" . __n('Click \'Continue\' to delete the following Data Collector.  Note, all devices will be disassociated from this Data Collector and mapped back to the Main Cacti Data Collector.', 'Click \'Continue\' to delete all following Data Collectors.  Note, all devices will be disassociated from these Data Collectors and mapped back to the Main Cacti Data Collector.', sizeof($poller_array)) . "</p>
@@ -286,7 +286,7 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Delete Data Collector', 'Delete Data Collectors', sizeof($poller_array)) . "'>";
-		}elseif (get_request_var('drp_action') == '2') { /* disable */
+		} elseif (get_request_var('drp_action') == '2') { // disable
 			print "<tr>
 				<td class='textArea' class='odd'>
 					<p>" . __n('Click \'Continue\' to disable the following Data Collector.', 'Click \'Continue\' to disable the following Data Collectors.', sizeof($poller_array)) . "</p>
@@ -295,7 +295,7 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Disable Data Collector', 'Disable Data Collectors', sizeof($poller_array)) . "'>";
-		}elseif (get_request_var('drp_action') == '3') { /* enable */
+		} elseif (get_request_var('drp_action') == '3') { // enable
 			print "<tr>
 				<td class='textArea' class='odd'>
 					<p>" . __n('Click \'Continue\' to enable the following Data Collector.', 'Click \'Continue\' to enable the following Data Collectors.', sizeof($poller_array)) . "</p>
@@ -304,7 +304,7 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Enable Data Collector', 'Enable Data Collectors', sizeof($poller_array)) . "'>";
-		}elseif (get_request_var('drp_action') == '4') { /* full sync */
+		} elseif (get_request_var('drp_action') == '4') { // full sync
 			print "<tr>
 				<td class='textArea' class='odd'>
 					<p>" . __n('Click \'Continue\' to Synchronize the Remote Data Collector for Offline Operation.', 'Click \'Continue\' to Synchronize the Remote Data Collectors for Offline Operation.', sizeof($poller_array)) . "</p>
@@ -314,7 +314,7 @@ function form_actions() {
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Enable Data Collector', 'Synchronize Remote Data Collectors', sizeof($poller_array)) . "'>";
 		}
-	}else{
+	} else {
 		print "<tr><td class='odd'><span class='textError'>" . __('You must select at least one Site.') . "</span></td></tr>\n";
 		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
 	}
@@ -349,13 +349,13 @@ function poller_edit() {
 	if (!isempty_request_var('id')) {
 		$poller = db_fetch_row_prepared('SELECT * FROM poller WHERE id = ?', array(get_request_var('id')));
 		$header_label = __('Site [edit: %s]', htmlspecialchars($poller['name']));
-	}else{
+	} else {
 		$header_label = __('Site [new]');
 	}
 
 	form_start('pollers.php', 'poller');
 
-	html_start_box($header_label, '100%', '', '3', 'center', '');
+	html_start_box($header_label, '100%', true, '3', 'center', '');
 
 	if (isset($poller) && sizeof($poller)) {
 		if ($poller['id'] == 1) {
@@ -376,12 +376,22 @@ function poller_edit() {
 		)
 	);
 
+	$tip_text = __('Remote Data Collectors must be able to communicate to the Main Data Collector, and vice versa.  Use this button to verify that the Main Data Collector can communicate to this Remote Data Collector.');
+
+	if (read_config_option('hide_form_description') == 'on') {
+		$tooltip = '<br><span class="formFieldDescription">' . $tip_text . '</span>';
+	} else {
+		$tooltip = '<div class="formTooltip">' . str_replace("\n", '', display_tooltip($tip_text)) . '</div>';
+	}
+
+	$row_html = '<div class="formRow odd"><div class="formColumnLeft"><div class="formFieldName">' . __('Test Database Connection') . $tooltip . '</div></div><div class="formColumnRight"><input id="dbtest" type="button" value="' . __('Test Connection') . '"><span id="results"></span></div></div>';
+
 	if (isset($poller) && sizeof($poller)) {
 		if ($poller['id'] > 1) {
 			?>
 			<script type='text/javascript'>
 			$(function() {
-				$('#row_dbssl').after('<tr class="odd"><td style="width:50%"></td><td><input id="dbtest" type="button" value="Test Database Connection"><span id="results"></span></td></tr>')
+				$('#row_dbssl').after('<?php print $row_html;?>');
 				applySkin();
 
 				$('#dbtest').click(function() {
@@ -392,10 +402,10 @@ function poller_edit() {
 			function ping_database() {
 				dbssl = $('#dbssl').is(':checked') ? 'on':'';
 
-				$.post('pollers.php', { 
+				$.post('pollers.php', {
 					__csrf_magic: csrfMagicToken,
 					action:       'ping',
-					dbdefault:    $('#dbdefault').val(), 
+					dbdefault:    $('#dbdefault').val(),
 					dbhost:       $('#dbhost').val(),
 					dbuser:       $('#dbuser').val(),
 					dbpass:       $('#dbpass').val(),
@@ -406,11 +416,11 @@ function poller_edit() {
 				});
 			}
 			</script>
-			<?php 
+			<?php
 		}
 	}
 
-	html_end_box();
+	html_end_box(true, true);
 
 	form_save_button('pollers.php', 'return');
 }
@@ -424,12 +434,12 @@ function test_database_connection($poller = array()) {
 			if ($field == 'dbssl') {
 				if (isset_request_var('dbssl') && get_nfilter_request_var('dbssl') == 'on') {
 					$poller['dbssl'] = true;
-				}else{
+				} else {
 					$poller['dbssl'] = false;
 				}
-			}elseif (isset_request_var($field)) {
+			} elseif (isset_request_var($field)) {
 				$poller[$field] = get_nfilter_request_var($field);
-			}else{
+			} else {
 				print 'ERROR: DB Connection Column ' . $field . ' Missing';
 				return false;
 			}
@@ -437,19 +447,19 @@ function test_database_connection($poller = array()) {
 	}
 
     $connection = db_connect_real(
-		$poller['dbhost'], 
-		$poller['dbuser'], 
-		$poller['dbpass'], 
-		$poller['dbdefault'], 
-		$poller['dbtype'], 
-		$poller['dbport'], 
+		$poller['dbhost'],
+		$poller['dbuser'],
+		$poller['dbpass'],
+		$poller['dbdefault'],
+		$poller['dbtype'],
+		$poller['dbport'],
 		$poller['dbssl']
 	);
 
     if (is_object($connection)) {
         db_close($connection);
         print 'Connection Successful';
-    }else{
+    } else {
         print 'Connection Failed';
     }
 }
@@ -460,28 +470,28 @@ function pollers() {
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'rows' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'page' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK, 
+			'filter' => FILTER_CALLBACK,
 			'pageset' => true,
-			'default' => '', 
+			'default' => '',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_column' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'name', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'name',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_direction' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'ASC', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
 			)
 	);
@@ -491,7 +501,7 @@ function pollers() {
 
 	if (get_request_var('rows') == '-1') {
 		$rows = read_config_option('num_rows_table');
-	}else{
+	} else {
 		$rows = get_request_var('rows');
 	}
 
@@ -510,7 +520,7 @@ function pollers() {
 						<input id='filter' type='text' name='filter' size='25' value='<?php print htmlspecialchars(get_request_var('filter'));?>'>
 					</td>
 					<td>
-						<?php print __('Rows');?>
+						<?php print __('Collectors');?>
 					</td>
 					<td>
 						<select id='rows' name='rows' onChange='applyFilter()'>
@@ -571,7 +581,7 @@ function pollers() {
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
 		$sql_where = "WHERE (name LIKE '%" . get_request_var('filter') . "%')";
-	}else{
+	} else {
 		$sql_where = '';
 	}
 
@@ -617,7 +627,7 @@ function pollers() {
 		foreach ($pollers as $poller) {
 			if ($poller['id'] == 1) {
 				$disabled = true;
-			}else{
+			} else {
 				$disabled = false;
 			}
 
@@ -642,7 +652,7 @@ function pollers() {
 			form_checkbox_cell($poller['name'], $poller['id'], $disabled);
 			form_end_row();
 		}
-	}else{
+	} else {
 		print "<tr class='tableRow'><td colspan='4'><em>" . __('No Data Collectors Found') . "</em></td></tr>\n";
 	}
 
